Diesel Derive More
Additional derive functionality for the diesel models which make it easier to get started
DBEnum
DBEnum provides diesel implementations for using an enum as a string field in models. Deriving DBEnum in an enum provides serializationa and deserialization traits.
DefaultInsertable
Default insertable provides a default implementation for a diesel model It allows marking fields as auto_increment so that they are excluded from the derived struct.
The new struct is prefixed with ‘New’ and lives in the same module as the original struct.
When using the serialization feature, the stuct is also serializable through serde
Examples
For examples of usage check the corresponding tests in the tests/ dir